@@ -1,5 +1,5 @@
 #!/bin/bash
-VERSION='0.7'
+VERSION='0.8'
 #
 # Copyright (C) 2002-2010  Ola Lundqvist <ola@inguza.com>
 # Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
@@ -576,14 +576,14 @@ HOST_IP=$(ip -4 -o addr show primary scope global dev "$INTERFACE" | \
     > "$VROOTDIR/$VHOST/etc/resolv.conf"
 
 # If there is a proxy server statement in-use in the Host server, copy it across
-if [ -f /etc/apt/apt.conf ]; then
-    cp /etc/apt/apt.conf $VROOTDIR/$VHOST/etc/apt/apt.conf
-fi
+#if [ -f /etc/apt/apt.conf ]; then
+#    cp /etc/apt/apt.conf $VROOTDIR/$VHOST/etc/apt/apt.conf
+#fi
 
 # support the apt.conf.d directories
-if [ -d /etc/apt/apt.conf.d ] ; then
-    cp -a /etc/apt/apt.conf.d/* $VROOTDIR/$VHOST/etc/apt/apt.conf.d/ > /dev/null 2>&1
-fi
+#if [ -d /etc/apt/apt.conf.d ] ; then
+#    cp -a /etc/apt/apt.conf.d/* $VROOTDIR/$VHOST/etc/apt/apt.conf.d/ > /dev/null 2>&1
+#fi
 
 # Create a dummy fstab
 cat << EOF > "$VROOTDIR/$VHOST/etc/fstab"
